@@ -213,13 +213,10 @@ class BranchTests(tests.TestCaseInTempDir):
         r.refs[b"refs/tags/lala"] = b"aa" * 20
         oldrepo = Repository.open(path)
         oldrepo.get_mapping().revision_id_foreign_to_bzr(gitsha)
-        warnings, newbranch = self.callCatchWarnings(self.clone_git_branch, path, "f")
+        newbranch = self.clone_git_branch(path, "f")
         self.assertEqual({}, newbranch.tags.get_tag_dict())
-        # Dulwich raises a UserWarning for tags with invalid target
-        self.assertIn(
-            ("ref refs/tags/lala points at non-present sha " + ("aa" * 20),),
-            [w.args for w in warnings],
-        )
+        # Check that a warning was logged for the tag with invalid target
+        self.assertIn("lala does not point to a valid object", self.get_log())
 
     def test_interbranch_pull_submodule(self):
         path = "d"
@@ -256,7 +253,7 @@ class BranchTests(tests.TestCaseInTempDir):
         )
 
     def test_interbranch_pull(self):
-        path, (gitsha1, gitsha2) = self.make_tworev_branch()
+        path, (_gitsha1, gitsha2) = self.make_tworev_branch()
         oldrepo = Repository.open(path)
         revid2 = oldrepo.get_mapping().revision_id_foreign_to_bzr(gitsha2)
         newbranch = self.make_branch("g")
@@ -265,7 +262,7 @@ class BranchTests(tests.TestCaseInTempDir):
         self.assertEqual(revid2, newbranch.last_revision())
 
     def test_interbranch_pull_noop(self):
-        path, (gitsha1, gitsha2) = self.make_tworev_branch()
+        path, (_gitsha1, gitsha2) = self.make_tworev_branch()
         oldrepo = Repository.open(path)
         revid2 = oldrepo.get_mapping().revision_id_foreign_to_bzr(gitsha2)
         newbranch = self.make_branch("g")
@@ -276,7 +273,7 @@ class BranchTests(tests.TestCaseInTempDir):
         self.assertEqual(revid2, newbranch.last_revision())
 
     def test_interbranch_pull_stop_revision(self):
-        path, (gitsha1, gitsha2) = self.make_tworev_branch()
+        path, (gitsha1, _gitsha2) = self.make_tworev_branch()
         oldrepo = Repository.open(path)
         revid1 = oldrepo.get_mapping().revision_id_foreign_to_bzr(gitsha1)
         newbranch = self.make_branch("g")
@@ -301,7 +298,7 @@ class BranchTests(tests.TestCaseInTempDir):
         self.assertTrue(newbranch.repository.has_revision(revid2))
 
     def test_bzr_branch_bound_to_git(self):
-        path, (gitsha1, gitsha2) = self.make_tworev_branch()
+        path, (_gitsha1, _gitsha2) = self.make_tworev_branch()
         wt = Branch.open(path).create_checkout("co")
         self.build_tree_contents([("co/foobar", b"blah")])
         self.assertRaises(
